@@ -3,7 +3,7 @@
  XMODEM file transfer protocol
 ===============================
 
-.. $Id: __init__.py,v 696ce0cd218b 2010/04/22 16:58:05 maze $
+.. $Id: __init__.py,v 71400c3c93f3 2010/06/24 09:01:19 maze $
 
 This is a literal implementation of XMODEM.TXT_, XMODEM1K.TXT_ and 
 XMODMCRC.TXT_, support for YMODEM and ZMODEM is pending. YMODEM should 
@@ -270,14 +270,18 @@ class XMODEM(object):
                         # excessive amounts of retransmissions requested, 
                         # abort transfer
                         self.abort(timeout=timeout)
+                        if not quiet:
+                            print >> sys.stderr, 'excessive NAKs'
                         return False
     
                 # protocol error
                 self.abort(timeout=timeout)
+                if not quiet:
+                    print >> sys.stderr, 'protocol error'
                 return False
 
             # keep track of sequence
-            sequence = (sequence + 1 ) % 0xff
+            sequence = (sequence + 1) % 0x100
 
         # end of transmission
         self.putc(EOT)
